summaryrefslogtreecommitdiffstats
path: root/Source/cmSystemTools.cxx
diff options
context:
space:
mode:
authorOrgad Shaneh <orgads@gmail.com>2021-04-01 17:03:52 (GMT)
committerBrad King <brad.king@kitware.com>2021-04-26 18:27:34 (GMT)
commitddcd1469e8377fe258913a20aa47e65f71f8695b (patch)
treed18b6561383a8f4bc206dac848a15814b74ca642 /Source/cmSystemTools.cxx
parentb3ca4f9ad18220b2f56cd6af7df5cf1e671d39a8 (diff)
downloadCMake-ddcd1469e8377fe258913a20aa47e65f71f8695b.zip
CMake-ddcd1469e8377fe258913a20aa47e65f71f8695b.tar.gz
CMake-ddcd1469e8377fe258913a20aa47e65f71f8695b.tar.bz2
MSYS: Add support for running under MSYS runtime environment
Detect MSYS as CYGWIN, with the required adaptations.
Diffstat (limited to 'Source/cmSystemTools.cxx')
-rw-r--r--Source/cmSystemTools.cxx6
1 files changed, 5 insertions, 1 deletions
diff --git a/Source/cmSystemTools.cxx b/Source/cmSystemTools.cxx
index 5382fac..aad5533 100644
--- a/Source/cmSystemTools.cxx
+++ b/Source/cmSystemTools.cxx
@@ -3239,10 +3239,14 @@ cm::string_view cmSystemTools::GetSystemName()
systemName = "kFreeBSD";
}
// fix for CYGWIN which has windows version in it
if (systemName.find("CYGWIN") != cm::string_view::npos) {
systemName = "CYGWIN";
}
+
+ if (systemName.find("MSYS") != cm::string_view::npos) {
+ systemName = "MSYS";
+ }
return systemName;
}
return "";
@@ -3239,10 +3239,14 @@ cm::string_view cmSystemTools::GetSystemName()
systemName = "kFreeBSD";
}
- // fix for CYGWIN which has windows version in it
+ // fix for CYGWIN and MSYS which have windows version in them
if (systemName.find("CYGWIN") != cm::string_view::npos) {
systemName = "CYGWIN";